/****************************************************************************
 Module
   SPI_C32_FSM.h

 Revision
   1.0.0

 Description
   This is the FSM for SPI communication on the COACH C32. The C32 is in Master mode 
   and communicates with two Slaves: 1) one input/output shift register combo and 
   2) one PIC16F690 connected to the Xbee24 radio module.

 Notes

 ME 218c -- Team 13: Enchantment Under the Sea
 Author: Buddy Gardineer
****************************************************************************/

#ifndef SPI_C32_FSM_H
#define SPI_C32_FSM_H

#include "ES_Configure.h"
#include "ES_Types.h"

// typedefs for the states
// State definitions for use with the query function
typedef enum { InitPseudoState, ShiftRegisterRW, TransmittingHeaderByte, 
					TransmittingDataByte, ParsingStatusByte } SPI_C32_FSM_t;

// Public Function Prototypes

bool InitSPI_C32_FSM ( uint8_t Priority );
bool PostSPI_C32_FSM( ES_Event ThisEvent );
ES_Event RunSPI_C32_FSM( ES_Event ThisEvent );
bool Calibrated(void);
void SetOrientationData(void);

#endif /* SPI_C32_FSM_H */

